<?php

	/**
	 * The admin-specific functionality of the plugin.
	 *
	 * @link       https://codeboxr.com/
	 * @since      1.0.0
	 *
	 * @package    Codeboxrflexiblecountdown
	 * @subpackage Codeboxrflexiblecountdown/admin
	 */

	/**
	 * The admin-specific functionality of the plugin.
	 *
	 * Defines the plugin name, version, and two examples hooks for how to
	 * enqueue the admin-specific stylesheet and JavaScript.
	 *
	 * @package    Codeboxrflexiblecountdown
	 * @subpackage Codeboxrflexiblecountdown/admin
	 * @author     Codeboxr <info@codeboxr.com>
	 */
	class Codeboxrflexiblecountdown_Admin {

		/**
		 * The ID of this plugin.
		 *
		 * @since    1.0.0
		 * @access   private
		 * @var      string $plugin_name The ID of this plugin.
		 */
		private $plugin_name;

		/**
		 * The version of this plugin.
		 *
		 * @since    1.0.0
		 * @access   private
		 * @var      string $version The current version of this plugin.
		 */
		private $version;

		/**
		 * The setting of this plugin.
		 *
		 * @since    1.0.0
		 * @access   private
		 * @var      string $version The current version of this plugin.
		 */
		private $settings_api;

		/**
		 * The plugin basename of the plugin.
		 *
		 * @since    1.0.0
		 * @access   protected
		 * @var      string $plugin_basename The plugin basename of the plugin.
		 */
		protected $plugin_basename;

		/**
		 * Initialize the class and set its properties.
		 *
		 * @since    1.0.0
		 *
		 * @param      string $plugin_name The name of this plugin.
		 * @param      string $version     The version of this plugin.
		 */
		public function __construct( $plugin_name, $version ) {

			$this->plugin_name = $plugin_name;
			$this->version     = $version;

			$this->plugin_basename = plugin_basename( plugin_dir_path( __DIR__ ) . $plugin_name . '.php' );

			//get instance of setting api
			$this->settings_api = new CBFC_Settings_API( $this->plugin_name, $this->version );
		}

		/**
		 * Add admin setting menu under setting
		 */
		public function plugin_admin_menu() {
			add_options_page(
				esc_html__( 'CBX Flexible Countdown (CBFC)', 'codeboxrflexiblecountdown' ),
				esc_html__( 'CBX Countdown Settings', 'codeboxrflexiblecountdown' ),
				'manage_options',
				'codeboxrflexiblecountdown',
				array( $this, 'display_plugin_admin_page' )
			);
		}

		/**
		 * Render the settings page for this plugin.
		 *
		 * @since    1.0.0
		 */
		public function display_plugin_admin_page() {
			$plugin_data = get_plugin_data( plugin_dir_path( __DIR__ ) . '/../' . $this->plugin_basename );
			include( 'partials/admin-settings-display.php' );
		}

		/**
		 * Initialize setting
		 */
		public function setting_init() {
			//set the settings
			$this->settings_api->set_sections( $this->get_settings_sections() );
			$this->settings_api->set_fields( $this->get_settings_fields() );
			//initialize settings
			$this->settings_api->admin_init();
		}

		/**
		 * Global Setting Sections and titles
		 *
		 * @return type
		 */
		public function get_settings_sections() {
			$settings_sections = array(

				array(
					'id'    => 'cbfc_general_settings',
					'title' => esc_html__( 'Default Settings', 'codeboxrflexiblecountdown' )
				),
				array(
					'id'    => 'cbfc_light_settings',
					'title' => esc_html__( 'Light Countdown Settings', 'codeboxrflexiblecountdown' )
				),
				array(
					'id'    => 'cbfc_circular_settings',
					'title' => esc_html__( 'Circular Countdown Settings', 'codeboxrflexiblecountdown' )
				),
				array(
					'id'    => 'cbfc_kk_settings',
					'title' => esc_html__( 'KK Countdown Settings', 'codeboxrflexiblecountdown' )
				),
				array(
					'id'    => 'cbfc_tools',
					'title' => esc_html__( 'Tools', 'codeboxrflexiblecountdown' )
				)

			);

			return apply_filters( 'cbfc_setting_sections', $settings_sections );
		}

		/**
		 * Global Setting Fields
		 *
		 * @return array
		 */
		public function get_settings_fields() {

			global $wpdb;

			$reset_data_link = add_query_arg( 'cbfc_fullreset', 1, admin_url( 'options-general.php?page=codeboxrflexiblecountdown' ) );

			$table_data_html = $table_cache_html = '';

			$table_data_html .= '<p id="cbxlatesttweets_tool_fullreset"><strong>' . esc_html__( 'Following option values created by this plugin(including addon)', 'codeboxrflexiblecountdown' ) . '</strong></p>';


			$option_values = CBFCHelper::getAllOptionNames();
			$table_counter = 1;
			foreach ( $option_values as $key => $value ) {
				$table_data_html .= '<p>' . str_pad( $table_counter, 2, '0', STR_PAD_LEFT ) . '. ' . $value['option_name'] . ' - ' . $value['option_id'] . ' - (<code style="overflow-wrap: break-word; word-break: break-all;">' . $value['option_value'] . '</code>)</p>';

				$table_counter ++;
			}

			$settings_builtin_fields =
				array(
					'cbfc_general_settings'  => array(
						array(
							'name'    => 'type',
							'label'   => esc_html__( 'Countdown Style', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'select',
							'options' => CBFCHelper::getCountdownStyles(),
							'default' => 'cbfc_light'
						),
						array(
							'name'    => 'date',
							'label'   => esc_html__( 'Launch Date', 'codeboxrflexiblecountdown' ),
							'type'    => 'datepicker',
							'desc'    => esc_html__( 'Date format: MM/DD/YYYY', 'codeboxrflexiblecountdown' ),
							'default' => CBFCHelper::getDefaultDate()
						),
						array(
							'name'    => 'hour',
							'label'   => esc_html__( 'Launch Hour', 'codeboxrflexiblecountdown' ),
							'desc'    => esc_html__( 'Max value is 23', 'codeboxrflexiblecountdown' ),
							'type'    => 'number',
							'size'    => 'hour',
							'default' => 0,
							'min'     => 0,
							'max'     => 23
						),
						array(
							'name'    => 'min',
							'label'   => esc_html__( 'Launch Minutes', 'codeboxrflexiblecountdown' ),
							'desc'    => esc_html__( 'Max value is 59', 'codeboxrflexiblecountdown' ),
							'type'    => 'number',
							'default' => 0,
							'size'    => 'minutes',
							'min'     => 0,
							'max'     => 59
						)
					),
					'cbfc_light_settings'  => array(
						array(
							'name'    => 'num_color',
							'label'   => esc_html__( 'Count Number Color', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#333'
						),
						array(
							'name'    => 'res_num_color',
							'label'   => esc_html__( 'Count Number Color (On Responsive)', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#333'
						),
						array(
							'name'    => 'num_bg_color',
							'label'   => esc_html__( 'Count Number Background Color', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#eaeaea'
						),
						array(
							'name'    => 'text_color',
							'label'   => esc_html__( 'Text Color', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#fff'
						),
						array(
							'name'    => 'res_text_color',
							'label'   => esc_html__( 'Text Color (On Responsive)', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#333'
						),
						array(
							'name'    => 'text_bg_color',
							'label'   => esc_html__( 'Text Background Color', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#f5832b'
						)
					),
					'cbfc_circular_settings' => array(
						array(
							'name'    => 'sec_color',
							'label'   => esc_html__( 'Seconds Border Color', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#7995D5'
						),
						array(
							'name'    => 'min_color',
							'label'   => esc_html__( 'Minutes Border Color', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#ACC742'
						),
						array(
							'name'    => 'hour_color',
							'label'   => esc_html__( 'Hours Border Color', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#ECEFCB'
						),
						array(
							'name'    => 'day_color',
							'label'   => esc_html__( 'Days Border Color', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#FF9900'
						),
						array(
							'name'    => 'canvas_color',
							'label'   => esc_html__( 'Background Color', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#9c9c9c'
						),
						array(
							'name'    => 'text_color',
							'label'   => esc_html__( 'Count Number And Text Color', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#ffffff'
						),
						array(
							'name'    => 'res_text_color',
							'label'   => esc_html__( 'Text Color (On Responsive)', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#333'
						),
						array(
							'name'    => 'border_width',
							'label'   => esc_html__( 'Circle Border Width', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'text',
							'default' => '6'
						),

					),
					'cbfc_kk_settings'       => array(
						array(
							'name'    => 'font_size',
							'label'   => esc_html__( 'Countdown Font Size', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'text',
							'default' => '30'
						),
						array(
							'name'    => 'num_color',
							'label'   => esc_html__( 'Countdown Number Color', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#3767b9'
						),

						array(
							'name'    => 'text_color',
							'label'   => esc_html__( 'Countdown Text Color', 'codeboxrflexiblecountdown' ),
							'desc'    => '',
							'type'    => 'color',
							'default' => '#666333'
						)
					),
					'cbfc_tools'             => array(
						'delete_global_config' => array(
							'name'    => 'delete_global_config',
							'label'   => esc_html__( 'On Uninstall delete plugin data', 'codeboxrflexiblecountdown' ),
							'desc'    => '<p>' . esc_html__( 'Delete Global Config data created by this plugin on uninstall.', 'codeboxrflexiblecountdown' ) . ' ' . __( 'Details <a data-target="cbxlatesttweets_tool_fullreset" class="cbxlatesttweets_jump" href="#">option values</a> and <a data-target="cbxlatesttweets_tool_cachereset" class="cbxlatesttweets_jump" href="#">transient values</a> ', 'codeboxrflexiblecountdown' ) . '</p>' . '<p>' . __( '<strong>Please note that this process can not be undone and it is recommended to keep full database backup before doing this.</strong>', 'codeboxrflexiblecountdown' ) . '</p>',
							'type'    => 'radio',
							'options' => array(
								'yes' => esc_html__( 'Yes', 'codeboxrflexiblecountdown' ),
								'no'  => esc_html__( 'No', 'codeboxrflexiblecountdown' ),
							),
							'default' => 'no'
						),
						'reset_data'           => array(
							'name'    => 'reset_data',
							'label'   => esc_html__( 'Reset all data', 'codeboxrflexiblecountdown' ),
							'desc'    => sprintf( __( 'Reset option values created by this plugin. 
<a class="button button-primary" onclick="return confirm(\'%s\')" href="%s">Reset Data</a>', 'codeboxrflexiblecountdown' ), esc_html__( 'Are you sure to reset all data, this process can not be undone?', 'codeboxrflexiblecountdown' ), $reset_data_link ) . $table_data_html,
							'type'    => 'html',
							'default' => 'off'
						),


					)
				);

			$settings_fields = array(); //final setting array that will be passed to different filters

			$sections = $this->get_settings_sections();


			foreach ( $sections as $section ) {
				if ( ! isset( $settings_builtin_fields[ $section['id'] ] ) ) {
					$settings_builtin_fields[ $section['id'] ] = array();
				}
			}

			foreach ( $sections as $section ) {
				$settings_builtin_fields_section_id = $settings_builtin_fields[ $section['id'] ];
				$settings_fields[ $section['id'] ]  = apply_filters( 'cbfc_global_' . $section['id'] . '_fields', $settings_builtin_fields_section_id );
			}


			$settings_fields = apply_filters( 'cbfc_global_fields', $settings_fields ); //final filter if need

			return $settings_fields;
		}

		/**
		 * Register the stylesheets for the admin area.
		 *
		 * @since    1.0.0
		 */
		public function enqueue_styles( $hook ) {
			if ( $hook == 'settings_page_codeboxrflexiblecountdown' ) {
				wp_enqueue_style( 'wp-color-picker' );

				wp_register_style( 'jquery-ui', plugin_dir_url( __FILE__ ) . '../assets/css/ui-lightness/jquery-ui.min.css', array(), $this->version );
				wp_register_style( 'chosen', plugin_dir_url( __FILE__ ) . '../assets/css/chosen.min.css', array(), $this->version, 'all' );
				wp_register_style( 'codeboxrflexiblecountdown-admin', plugin_dir_url( __FILE__ ) . '../assets/css/codeboxrflexiblecountdown-admin.css', array(
					'chosen',
					'jquery-ui',
					'wp-color-picker'
				), $this->version, 'all' );

				wp_enqueue_style( 'chosen' );
				wp_enqueue_style( 'jquery-ui' );
				wp_enqueue_style( 'codeboxrflexiblecountdown-admin' );
			}
		}//end method enqueue_styles

		/**
		 * Register the JavaScript for the admin area.
		 *
		 * @since    1.0.0
		 */
		public function enqueue_scripts( $hook ) {
			if ( $hook == 'settings_page_codeboxrflexiblecountdown' ) {
				wp_enqueue_script( 'jquery' );

				wp_enqueue_media();
				wp_enqueue_script( 'wp-color-picker' );
				wp_register_script( 'chosen-jquery', plugin_dir_url( __FILE__ ) . '../assets/js/chosen.jquery.min.js', array( 'jquery' ), $this->version, true );
				wp_register_script( 'codeboxrflexiblecountdown-admin', plugin_dir_url( __FILE__ ) . '../assets/js/codeboxrflexiblecountdown-admin.js', array(
					'jquery',
					'jquery-ui-core',
					'jquery-ui-datepicker',
					'chosen-jquery',
					'wp-color-picker'
				), $this->version, true );

				wp_enqueue_script( 'chosen-jquery' );
				wp_enqueue_script( 'codeboxrflexiblecountdown-admin' );
			}
		}//end method enqueue_scripts

		/**
		 * Full plugin reset and redirect
		 */
		public function plugin_fullreset() {
			global $wpdb;

			$option_prefix = 'cbfc_';

			$option_values = CBFCHelper::getAllOptionNames();

			foreach ( $option_values as $key => $accounting_option_value ) {
				delete_option( $accounting_option_value['option_name'] );
			}

			do_action( 'cbfc_plugin_option_delete' );


			// create plugin's core table tables
			activate_codeboxrflexiblecountdown();


			$this->settings_api->set_sections( $this->get_settings_sections() );
			$this->settings_api->set_fields( $this->get_settings_fields() );
			$this->settings_api->admin_init();

			wp_safe_redirect( admin_url( 'options-general.php?page=codeboxrflexiblecountdown#cbfc_tools' ) );
			exit();
		}//end method plugin_fullreset

	}//end class Codeboxrflexiblecountdown_Admin