<?php
	// If this file is called directly, abort.
	if ( ! defined( 'WPINC' ) ) {
		die;
	}

	/**
	 * Class CBFCHelper
	 *
	 */
	class CBFCHelper {

		/**
		 * @return mixed|void
		 */
		public static function getCountdownStyles() {
			$styles = array(
				'light'    => esc_html__('Light Countdown', 'codeboxrflexiblecountdown'),
				'circular' => esc_html__( 'Circular Countdown', 'codeboxrflexiblecountdown' ),
				'kk'       => esc_html__( 'KK Countdown', 'codeboxrflexiblecountdown' )
			);

			return apply_filters('cbfc_countdown_styles', $styles);
		}

		/**
		 * List all global option name with prefix cbxlatesttweets_
		 */
		public static function getAllOptionNames() {
			global $wpdb;

			$prefix       = 'cbfc_';
			$option_names = $wpdb->get_results( "SELECT * FROM {$wpdb->options} WHERE option_name LIKE '{$prefix}%'", ARRAY_A );

			return apply_filters( 'cbfc_option_names', $option_names );
		}//end method getAllOptionNames

		/**
		 * Return default date
		 *
		 * @return string
		 */
		public static function getDefaultDate() {
			$month = ( date( 'm' ) == 12 || date( 'm' ) == '12' ) ? '01' :  ( date( 'm' ) + 1 );
			$year = ( date( 'm' ) == 12 || date( 'm' ) == '12' ) ? ( date( 'Y' ) + 1 ) : date( 'Y' );
			return $date = $month .'/26/' .$year;
		}//end method getDefaultDate

		/**
		 * Get countdown
		 *
		 * @param array $attr
		 * @param bool $echo
		 *
		 * @return mixed|void
		 */
		public static function getFlexibleCountdown($attr, $echo = false){
			$plugin_public = new Codeboxrflexiblecountdown_Public( CBFC_PLUGIN_NAME, CBFC_PLUGIN_VERSION );

			if($echo == true) echo $plugin_public->get_flexible_countdown($attr);
			else return $plugin_public->get_flexible_countdown($attr);
		}//end method getFlexibleCountdown

		/**
		 * Return countdown style
		 *
		 * @param $attr
		 *
		 * @return string
		 */
		public static function getFlexibleCountdownHtml($attr){

			$countdown_html = '';

			if($attr['type'] == '') $attr['type'] = 'light';

			$type = $attr['type'];


			if ( $attr['type'] == 'cbfc_light' or $attr['type'] == 'light' or empty($attr['type']) ) {
				//include css and js for light countdown
				//CBFCHelper::loadCBFCLightStyle();
				//CBFCHelper::loadCBFCLightJS();

				CBFCHelper::loadCSS();
				CBFCHelper::loadJS();

				static $cbfc_light_counter = 0;
				$cbfc_light_counter++;

				ob_start();
				include( apply_filters('cbfccountdown_template', CBFC_PLUGIN_ROOT_PATH . 'templates/light.php', 'light', $attr) );
				$countdown_html = ob_get_contents();
				ob_end_clean();

			}
			else if ( $attr['type'] == 'cbfc_circular'  or $attr['type'] == 'circular' ) {
				//include css and js for circular countdown
				//CBFCHelper::loadCBFCCircularStyle();
				//CBFCHelper::loadCBFCCircularJS();

				CBFCHelper::loadCSS();
				CBFCHelper::loadJS();

				static $cbfc_circular_counter = 0;
				$cbfc_circular_counter++;
				ob_start();
				include( apply_filters('cbfccountdown_template',CBFC_PLUGIN_ROOT_PATH . 'templates/circular.php', 'circular', $attr) );
				$countdown_html = ob_get_contents();
				ob_end_clean();
			}
			else if ( $attr['type'] == 'cbfc_kk'  or $attr['type'] == 'kk' ) {
				//include css and js for kk countdown
				//CBFCHelper::loadCBFCKKStyle();
				//CBFCHelper::loadCBFCKKJS();

				CBFCHelper::loadCSS();
				CBFCHelper::loadJS();

				static $cbfc_kk_counter = 0;
				$cbfc_kk_counter++;
				ob_start();
				include( apply_filters('cbfccountdown_template', CBFC_PLUGIN_ROOT_PATH . 'templates/kk.php', 'kk', $attr) );
				$countdown_html = ob_get_contents();
				ob_end_clean();
			}

			return apply_filters('cbfccountdown_html', $countdown_html, $attr);
		}//end method getFlexibleCountdownHtml

		/**
		 * Load light count down style
		 */
		public static function loadCBFCLightStyle(){
			//wp_enqueue_style('cbfc-light-countdown');
		}//end method loadCBFCLightStyle

		/**
		 * Load light count down JS
		 */
		public static function loadCBFCLightJS(){
			//wp_enqueue_script( 'cbfc-light-countdown');
			//wp_enqueue_script( 'codeboxrflexiblecountdown-public');
		}//end method loadCBFCLightJS


		/**
		 * Load circular count down style
		 */
		public static function loadCBFCCircularStyle(){
			//wp_enqueue_style('cbfc-circular-countdown');
		}//end method loadCBFCCircularStyle

		/**
		 * Load light count down JS
		 */
		public static function loadCBFCCircularJS(){
			//wp_enqueue_script( 'kinetic');
			//wp_enqueue_script( 'cbfc-circular-countdown');
			//wp_enqueue_script( 'codeboxrflexiblecountdown-public');
		}//end method loadCBFCCircularJS

		/**
		 * Load circular count down style
		 */
		public static function loadCBFCKKStyle(){
			//wp_enqueue_style('cbfc-kk-countdown');
		}//end method loadCBFCKKStyle

		/**
		 * Load light count down JS
		 */
		public static function loadCBFCKKJS(){
			//wp_enqueue_script( 'cbfc-kkcountdown-countdown');
			//wp_enqueue_script( 'codeboxrflexiblecountdown-public');
		}//end method loadCBFCKKJS

		/**
		 * Load all countdown styles
		 */
		public static function loadCSS(){
			wp_enqueue_style( 'codeboxrflexiblecountdown-public');
		}

		/**
		 * Load all countdown js
		 */
		public static function loadJS(){
			wp_enqueue_script( 'codeboxrflexiblecountdown-public');
		}
	}//end class CBFCHelper