<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://codeboxr.com/
 * @since      1.0.0
 *
 * @package    Codeboxrflexiblecountdown
 * @subpackage Codeboxrflexiblecountdown/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Codeboxrflexiblecountdown
 * @subpackage Codeboxrflexiblecountdown/public
 * @author     Codeboxr <info@codeboxr.com>
 */
class Codeboxrflexiblecountdown_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name  = $plugin_name;
		$this->version      = $version;

		//get instance of setting api
		$this->settings_api = new CBFC_Settings_API( $this->plugin_name, $this->version );

		add_shortcode( 'cbfccountdown', array( $this, 'get_flexible_countdown' ) );

	}

	/**
	 * Add this public method for getting countdown using shortcode
	 *
	 * @since    1.0.0
	 *
	 * @return mixed|void
	 */
	public function get_flexible_countdown($atts) {

		$setting = $this->settings_api;

		$attr = shortcode_atts( array(
			//default setting
			'type'         => $setting->get_option( 'type', 'cbfc_general_settings', 'light' ),
			'date'         => $setting->get_option( 'date', 'cbfc_general_settings', CBFCHelper::getDefaultDate() ),
			'hour'         => $setting->get_option( 'hour', 'cbfc_general_settings', 0 ),
			'minute'       => $setting->get_option( 'min', 'cbfc_general_settings', 0 ),
			//light setting
			'l_numclr'     => $setting->get_option( 'num_color', 'cbfc_light_settings', '#333' ),
			//light number color
			'l_resnumclr'  => $setting->get_option( 'res_num_color', 'cbfc_light_settings', '#333' ),
			//light number responsive color
			'l_numbgclr'   => $setting->get_option( 'num_bg_color', 'cbfc_light_settings', '#eaeaea' ),
			// light number background color
			'l_textclr'    => $setting->get_option( 'text_color', 'cbfc_light_settings', '#fff' ),
			//light text color
			'l_restextclr' => $setting->get_option( 'res_text_color', 'cbfc_light_settings', '#333' ),
			//light text responsive color
			'l_textbgclr'  => $setting->get_option( 'text_bg_color', 'cbfc_light_settings', '#f5832b' ),
			//light text background
			//circular setting
			'c_secbclr'    => $setting->get_option( 'sec_color', 'cbfc_circular_settings', '#7995D5' ),
			//sec border color(circular)
			'c_minbclr'    => $setting->get_option( 'min_color', 'cbfc_circular_settings', '#ACC742' ),
			// min border  color(circular)
			'c_hourbclr'   => $setting->get_option( 'hour_color', 'cbfc_circular_settings', '#ECEFCB' ),
			//hour border color(circular)
			'c_daybclr'    => $setting->get_option( 'day_color', 'cbfc_circular_settings', '#FF9900' ),
			//days border color(circular)
			'c_bgclr'      => $setting->get_option( 'canvas_color', 'cbfc_circular_settings', '#9c9c9c' ),
			//canvas background color(circular)
			'c_textclr'    => $setting->get_option( 'text_color', 'cbfc_circular_settings', '#7995D5' ),
			//count number and text color(circular)
			'c_restextclr' => $setting->get_option( 'res_text_color', 'cbfc_circular_settings', '#7995D5' ),
			//text color on responsive(circular)
			'c_borderw' => $setting->get_option( 'border_width', 'cbfc_circular_settings', '6' ),
			//text color on responsive(circular)
			//kk setting
			'kk_fontsize'  => $setting->get_option( 'font_size', 'cbfc_kk_settings', '#7995D5' ),
			//kk font size
			'kk_numclr'    => $setting->get_option( 'num_color', 'cbfc_kk_settings', '#7995D5' ),
			//kk count down number color
			'kk_textclr'   => $setting->get_option( 'text_color', 'cbfc_kk_settings', '#7995D5' )
			//kk countdown text color
		), $atts, 'cbfccountdown' );

		return CBFCHelper::getFlexibleCountdownHtml($attr);
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		//wp_register_style('cbfc-circular-countdown', plugin_dir_url( __FILE__ ) . '../assets/css/cbfc-circular-countdown.css', array(), $this->version, 'all' );
		//wp_register_style('cbfc-light-countdown', plugin_dir_url( __FILE__ ) . '../assets/css/cbfc-light-countdown.css', array(), $this->version, 'all' );
		//wp_register_style('cbfc-kk-countdown', plugin_dir_url( __FILE__ ) . '../assets/css/cbfc-kk-countdown.css', array(), $this->version, 'all' );

		wp_register_style('codeboxrflexiblecountdown-public', plugin_dir_url( __FILE__ ) . '../assets/css/codeboxrflexiblecountdown-public.css', array(), $this->version, 'all' );
	}//end method enqueue_styles

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		$translation_strings = array(
			'kkc_day'   => esc_html__( 'day', 'codeboxrflexiblecountdown' ),
			'kkc_days'  => esc_html__( 'days', 'codeboxrflexiblecountdown' ),
			'kkc_hr'    => esc_html__( 'h', 'codeboxrflexiblecountdown' ),
			'kkc_min'   => esc_html__( 'm', 'codeboxrflexiblecountdown' ),
			'kkc_sec'   => esc_html__( 's', 'codeboxrflexiblecountdown' ),
		);



		/*wp_register_script( 'kinetic', plugin_dir_url( __FILE__ ) . '../assets/js/circular/kinetic-v5.1.0.js', array( ), $this->version, true );
		wp_register_script( 'cbfc-circular-countdown', plugin_dir_url( __FILE__ ) . '../assets/js/circular/circular-countdown.js', array( 'jquery', 'kinetic' ), $this->version, true );

		wp_register_script( 'cbfc-light-countdown', plugin_dir_url( __FILE__ ) . '../assets/js/light/jquery.light.countdown.js', array( 'jquery' ), $this->version, true );


		wp_register_script( 'cbfc-kkcountdown-countdown', plugin_dir_url( __FILE__ ) . '../assets/js/kk/kkcountdown.min.js', array( 'jquery' ), $this->version, true );*/

		wp_register_script( 'codeboxrflexiblecountdown-public', plugin_dir_url( __FILE__ ) . '../assets/js/codeboxrflexiblecountdown-public.js', array( 'jquery' ), $this->version, true );
		wp_localize_script( 'codeboxrflexiblecountdown-public', 'cbfc_strings', $translation_strings );
	}//end method enqueue_scripts

	/**
	 * Register widget
	 */
	public function register_widget(){
		register_widget("CodeboxrFlexibleCountdownWidget");
	}
}
